@@ -3,7 +3,7 @@ CONFIG = {}
 GLOBAL = {}
 SUBS = {}
 DYNE = {
-    "corn": ["corn"],
+    "grains": ["grains"],
     "exec": ["exec"],
     "states": ["states"],
 }
